==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/fr.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Information CPU non disponible",
    "Load average" : "Moyenne de la charge système",
    "Last minute" : "Dernière minute",
    "Memory info not available" : "Informations mémoire non disponibles",
    "Total" : "Total",
    "Current usage" : "Utilisation actuelle",
    "Users" : "Utilisateurs",
    "Groups" : "Groupes",
    "Links" : "Liens",
    "Mails" : "Courriels",
    "Federated sent" : "Federated envoyé",
    "Federated received" : "Federated reçu",
    "Talk conversations" : "Conversations orales",
    "Last 24 hours" : "24 dernières heures",
    "Last 1 hour" : "Dernière heure",
    "Last 5 mins" : "5 dernières minutes",
    "Copy" : "Copier",
    "Copied!" : "Copié !",
    "Not supported!" : "Non supporté !",
    "Press ⌘-C to copy." : "Pressez ⌘-C pour copier.",
    "Press Ctrl-C to copy." : "Pressez Ctrl-C pour copier.",
    "Monitoring" : "Surveillance",
    "Monitoring app with useful server information" : "Application de surveillance avec les informations utiles du serveur",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fournit des informations utiles sur le serveur, telles que la charge du processeur, l'utilisation de la RAM, l'utilisation du disque, le nombre d'utilisateurs, etc.",
    "CPU load" : "Charge CPU",
    "Memory usage" : "Utilisation mémoire",
    "Active users" : "Utilisateurs actifs",
    "Shares" : "Partages",
    "Storage" : "Stockage",
    "Users:" : "Utilisateurs :",
    "Files:" : "Fichiers :",
    "Storages:" : "Stockages :",
    "Free Space:" : "Espace libre :",
    "Nextcloud" : "Nextcloud",
    "Version:" : "Version :",
    "Apps installed:" : "Applications installées :",
    "Apps updates available:" : "Mises à jour d'applications disponibles :",
    "PHP" : "PHP",
    "Memory Limit:" : "Limite de mémoire :",
    "Max Execution Time:" : "Temps d’exécution maximal :",
    "Upload max size:" : "Taille de téléversement maximale :",
    "Database" : "Base de données",
    "Type:" : "Type :",
    "Size:" : "Taille :",
    "External monitoring tool" : "Outil de surveillance externe",
    "You can connect an external monitoring tool by using this end point:" : "Vous pouvez connecter un outil de surveillance externe en utilisant ce point d'extrémité :",
    "Did you know?" : "Le saviez-vous ?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "En ajoutant \"?format=json\" à la fin de l'adresse URL, cela vous donne le résultat dans le format JSON !"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-19.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/fr.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Information CPU non disponible",
    "Load average" : "Moyenne de la charge système",
    "Last minute" : "Dernière minute",
    "Memory info not available" : "Informations mémoire non disponibles",
    "Total" : "Total",
    "Current usage" : "Utilisation actuelle",
    "Users" : "Utilisateurs",
    "Groups" : "Groupes",
    "Links" : "Liens",
    "Mails" : "Courriels",
    "Federated sent" : "Federated envoyé",
    "Federated received" : "Federated reçu",
    "Talk conversations" : "Conversations orales",
    "24 hours" : "24 heures",
    "1 hour" : "1 heure",
    "5 mins" : "5 mins",
    "Copy" : "Copier",
    "Copied!" : "Copié !",
    "Not supported!" : "Non supporté !",
    "Press ⌘-C to copy." : "Pressez ⌘-C pour copier.",
    "Press Ctrl-C to copy." : "Pressez Ctrl-C pour copier.",
    "System" : "Système",
    "Monitoring" : "Surveillance",
    "Monitoring app with useful server information" : "Application de surveillance avec les informations utiles du serveur",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fournit des informations utiles sur le serveur, telles que la charge du processeur, l'utilisation de la RAM, l'utilisation du disque, le nombre d'utilisateurs, etc.",
    "Operating System" : "Système d'exploitation",
    "CPU" : "CPU",
    "Memory" : "Mémoire",
    "Server time" : "Heure du serveur",
    "Uptime" : "Durée de fonctionnement",
    "Time Servers" : "Serveurs de temps",
    "Load" : "Charge",
    "Disk" : "Disque",
    "Mount" : "Montage",
    "Filesystem" : "Système de fichiers",
    "Size" : "Taille",
    "Available" : "Disponible",
    "Used" : "Utilisé",
    "You will get a notification once one of your disks is nearly full." : "Vous recevrez une notification une fois que l’un de vos disques sera presque plein.",
    "Files:" : "Fichiers :",
    "Storages:" : "Stockages :",
    "Free Space:" : "Espace libre :",
    "Network" : "Réseau",
    "Hostname" : "Nom de l'hôte",
    "DNS" : "DNS",
    "Gateway" : "Passerelle",
    "Status" : "État",
    "Speed" : "Vitesse",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Utilisateurs actifs",
    "Total users:" : "Nombre total d'utilisateurs :",
    "Shares" : "Partages",
    "PHP" : "PHP",
    "Version:" : "Version :",
    "Memory Limit:" : "Limite de mémoire :",
    "Max Execution Time:" : "Temps d’exécution maximal :",
    "Upload max size:" : "Taille de téléversement maximale :",
    "Database" : "Base de données",
    "Type:" : "Type :",
    "Size:" : "Taille :",
    "External monitoring tool" : "Outil de surveillance externe",
    "You can connect an external monitoring tool by using this end point:" : "Vous pouvez connecter un outil de surveillance externe en utilisant ce point d'extrémité :",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Ajoutez \"?format=json\" à la fin de l'URL pour obtenir le résultat au format JSON. ",
    "Last 24 hours" : "24 dernières heures",
    "Last 1 hour" : "Dernière heure",
    "Last 5 mins" : "5 dernières minutes",
    "CPU load" : "Charge CPU",
    "Memory usage" : "Utilisation mémoire",
    "Storage" : "Stockage",
    "Users:" : "Utilisateurs :",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "Applications installées :",
    "Apps updates available:" : "Mises à jour d'applications disponibles :",
    "Did you know?" : "Le saviez-vous ?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "En ajoutant \"?format=json\" à la fin de l'adresse URL, cela vous donne le résultat dans le format JSON !"
},
"nplurals=2; plural=(n > 1);");
